@@ -1,4 +1,5 @@
 import os
+import sys
 
 from sybil import Sybil
 from doctest import ELLIPSIS, REPORT_NDIFF, NORMALIZE_WHITESPACE
@@ -6,12 +7,19 @@ from contextlib import ExitStack
 from sybil.parsers.doctest import DocTestParser
 from sybil.parsers.codeblock import CodeBlockParser
 
+# For the message catalog used in the doctests.
+from test.data import messages
+
+
+DOCTEST_FLAGS = ELLIPSIS | NORMALIZE_WHITESPACE | REPORT_NDIFF
+
 
 class DoctestNamespace:
     def __init__(self):
         self._resources = ExitStack()
 
     def setup(self, namespace):
+        sys.modules['messages'] = messages
         namespace['cleanups'] = self._resources
         # Ensure that environment variables affecting translation are
         # neutralized.
@@ -20,13 +28,12 @@ class DoctestNamespace:
                 del os.environ[envar]
 
     def teardown(self, namespace):
+        del sys.modules['messages']
         self._resources.close()
 
 
 namespace = DoctestNamespace()
 
-DOCTEST_FLAGS = ELLIPSIS | NORMALIZE_WHITESPACE | REPORT_NDIFF
-
 
 pytest_collect_file = Sybil(
     parsers=[
